<?php
/**
 * Plugin Name: Packstatus für WooCommerce
 * Plugin URI: https://www.bremersystems.eu
 * Description: Fügt einen Packstatus für Bestellungen hinzu, unabhängig vom WooCommerce-Bestellstatus.
 * Version: 1.3
 * Author: Karsten Bremer
 * Author URI: https://www.bremersystems.eu
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

define( 'PACKSTATUS_META_KEY', '_packstatus' );

function ps_get_packstatus_options() {
    return [
        'offen'             => 'Offen',
        'wird_bearbeitet'   => 'Wird bearbeitet',
        'on_hold'           => 'On Hold',
        'fertig'            => 'Fertig',
    ];
}

// ✅ Spalte in der Übersicht
add_filter( 'manage_edit-shop_order_columns', function( $columns ) {
    $new_columns = [];

    foreach ( $columns as $key => $column ) {
        $new_columns[ $key ] = $column;

        if ( 'order_status' === $key ) {
            $new_columns['packstatus'] = 'Packstatus';
        }
    }

    return $new_columns;
} );

// ✅ Packstatus ausgeben
add_action( 'manage_shop_order_posts_custom_column', function( $column, $post_id ) {
    if ( 'packstatus' === $column ) {
        $packstatus = get_post_meta( $post_id, PACKSTATUS_META_KEY, true ) ?: 'offen';

        $labels = ps_get_packstatus_options();
        $colors = [
            'offen'            => '#FFA500',
            'wird_bearbeitet'  => '#228B22',
            'on_hold'          => '#DC143C',
            'fertig'           => '#B0B0B0',
        ];

        $label = $labels[ $packstatus ] ?? 'Offen';
        $color = $colors[ $packstatus ] ?? '#ccc';

        echo '<span style="display:inline-block; padding:4px 8px; border-radius:3px; background:' . esc_attr( $color ) . '; color:#fff;">' . esc_html( $label ) . '</span>';
    }
}, 10, 2 );

// ✅ Metabox für Einzelbearbeitung
add_action( 'add_meta_boxes', function() {
    add_meta_box( 'packstatus_metabox', 'Packstatus', function( $post ) {
        $packstatus = get_post_meta( $post->ID, PACKSTATUS_META_KEY, true ) ?: 'offen';
        wp_nonce_field( 'ps_save_packstatus', 'ps_packstatus_nonce' );

        echo '<select name="ps_packstatus" style="width:100%;">';
        foreach ( ps_get_packstatus_options() as $key => $label ) {
            printf( '<option value="%s"%s>%s</option>', esc_attr( $key ), selected( $packstatus, $key, false ), esc_html( $label ) );
        }
        echo '</select>';
    }, 'shop_order', 'side', 'core' );
} );

// ✅ Speichern beim Update
add_action( 'save_post_shop_order', function( $post_id ) {
    if ( isset( $_POST['ps_packstatus_nonce'] ) && wp_verify_nonce( $_POST['ps_packstatus_nonce'], 'ps_save_packstatus' ) ) {
        if ( isset( $_POST['ps_packstatus'] ) ) {
            update_post_meta( $post_id, PACKSTATUS_META_KEY, sanitize_text_field( $_POST['ps_packstatus'] ) );
        }
    }
} );

// ✅ Bulk Actions hinzufügen
add_filter( 'bulk_actions-edit-shop_order', function( $actions ) {
    $packstatus_options = ps_get_packstatus_options();

    foreach ( $packstatus_options as $key => $label ) {
        $actions[ 'packstatus_' . $key ] = 'Packstatus ändern zu ' . $label;
    }

    return $actions;
} );

// ✅ Bulk Handler
add_filter( 'handle_bulk_actions-edit-shop_order', function( $redirect_to, $action, $post_ids ) {
    if ( strpos( $action, 'packstatus_' ) === 0 ) {
        $new_status = str_replace( 'packstatus_', '', $action );

        foreach ( $post_ids as $post_id ) {
            update_post_meta( $post_id, PACKSTATUS_META_KEY, sanitize_text_field( $new_status ) );
        }

        $redirect_to = add_query_arg( 'packstatus_updated', count( $post_ids ), $redirect_to );
    }

    return $redirect_to;
}, 10, 3 );

// ✅ Admin Hinweis nach Erfolg
add_action( 'admin_notices', function() {
    if ( isset( $_GET['packstatus_updated'] ) ) {
        printf( '<div id="message" class="updated notice notice-success is-dismissible"><p>%s Packstatus aktualisiert.</p></div>', intval( $_GET['packstatus_updated'] ) );
    }
} );
